'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Keypair = require('./Keypair.cjs');

const signerIdentity = (signer, setPayer = true) => ({
  install(umi) {
    umi.identity = signer;
    if (setPayer) {
      umi.payer = signer;
    }
  }
});
const signerPayer = signer => ({
  install(umi) {
    umi.payer = signer;
  }
});
const generatedSignerIdentity = (setPayer = true) => ({
  install(umi) {
    const signer = Keypair.generateSigner(umi);
    umi.use(signerIdentity(signer, setPayer));
  }
});
const generatedSignerPayer = () => ({
  install(umi) {
    const signer = Keypair.generateSigner(umi);
    umi.use(signerPayer(signer));
  }
});
const keypairIdentity = (keypair, setPayer = true) => ({
  install(umi) {
    const signer = Keypair.createSignerFromKeypair(umi, keypair);
    umi.use(signerIdentity(signer, setPayer));
  }
});
const keypairPayer = keypair => ({
  install(umi) {
    const signer = Keypair.createSignerFromKeypair(umi, keypair);
    umi.use(signerPayer(signer));
  }
});

exports.generatedSignerIdentity = generatedSignerIdentity;
exports.generatedSignerPayer = generatedSignerPayer;
exports.keypairIdentity = keypairIdentity;
exports.keypairPayer = keypairPayer;
exports.signerIdentity = signerIdentity;
exports.signerPayer = signerPayer;
//# sourceMappingURL=SignerPlugins.cjs.map
